---
title: <span class="badge object-type-scalar"></span> FeetSecSquared
---
# <span class="badge object-type-scalar"></span> FeetSecSquared

Acceleration: Feet/sec² (f/sec²)

## Definition

```python
# Acceleration: Feet/sec² (f/sec²)
FeetSecSquared: typing.Literal["accFS2"] = "accFS2"
```
